@@ -30,7 +30,7 @@ class AbstractSurface(ABC):
 
     def _create_lines(self, surf_type: str):
         self.line += f'surf            '
-        self.line += f'{self.name:15} {surf_type:15} '
+        self.line += f's{self.name:15} {surf_type:15} '
         for param in self.params:
             self.line += f'{param:10} '
         self.line += f'\n'
@@ -122,12 +122,35 @@ class Surface:
                 raise AttributeError('Wrong parameters number, loot at the class description')
             pass
 
+    class Hexxc(AbstractSurface):
+        def __init__(self, name:str, params: list[float | int]):
+            super().__init__(name, params)
+            super()._create_lines('hexxc')
+
+        def _check_surf_parameters(self):
+            if len(self.params) != 3:
+                logger.error('Wrong parameters number, loot at the class description')
+                raise AttributeError('Wrong parameters number, loot at the class description')
+
+    class Hexxap(AbstractSurface):
+        def __init__(self, name: str, params: list[float | int]):
+            super().__init__(name, params)
+            super()._create_lines('hexxc')
+
+        def _check_surf_parameters(self):
+            if len(self.params) != 5:
+                logger.error('Wrong parameters number, loot at the class description')
+                raise AttributeError('Wrong parameters number, loot at the class description')
+
 
 if __name__ == '__main__':
     surf = Surface().Cylz('surfc', [2, 3.0, 1.0])
     surf1 = Surface().Cylz('surfc', [1, 3, 1.0])
     surf2 = Surface().Cyl('surfc', [1, 3, 1.0])
 
+    surf3 = Surface.Hexxc('surfc', [1, 3, 1.0])
+
     print(surf)
     print(surf2)
+    print(surf3)
     print(Surface.instances)
